@@ -52,7 +52,7 @@
       (bg-dim      "#483426")
       (fg-dim      "#90918a")
       (bg-alt      "#59463f")
-      (fg-alt      "#a2c080")
+      (fg-alt      "#ccaa70")
 
       (bg-active   "#79665f")
       (bg-inactive "#3d2e1f")
@@ -242,6 +242,7 @@
 
 ;;;; Search mappings
 
+      (bg-search-match bg-warning)
       (bg-search-current bg-yellow-intense)
       (bg-search-lazy bg-blue-intense)
       (bg-search-replace bg-red-intense)
